@@ -14,6 +14,9 @@ from requests.exceptions import ConnectionError as ReqConnectionError
 from dataquality import __version__ as dq_version
 from dataquality.exceptions import GalileoException
 from dataquality.schemas.task_type import TaskType
+from dataquality.utils.helpers import galileo_disabled
+
+CLOUD_URL = "https://console.cloud.rungalileo.io"
 
 
 class GalileoConfigVars(str, Enum):
@@ -84,6 +87,8 @@ def set_platform_urls(console_url_str: str) -> None:
         os.environ[GalileoConfigVars.API_URL] = "http://localhost:8088"
     else:
         api_url = console_url_str.replace("console.", "api.").rstrip("/")
+        api_url = f"https://{api_url}" if not api_url.startswith("http") else api_url
+        api_url = api_url.replace("http://", "https://")
         _validate_api_url(console_url_str, api_url)
         os.environ[GalileoConfigVars.API_URL] = api_url
 
@@ -97,7 +102,7 @@ def _validate_api_url(console_url: str, api_url: str) -> None:
         "and then \n`dq.configure()`"
         "\n\nDetail: {err}"
     )
-    url = f"http://{api_url}" if not api_url.startswith("http") else api_url
+    url = f"https://{api_url}" if not api_url.startswith("http") else api_url
     try:
         r = requests.get(f"{url}/healthcheck")
         if not r.ok:
@@ -123,8 +128,8 @@ def _check_console_url() -> None:
             set_platform_urls(console_url_str=console_url)
 
 
-def set_config() -> Config:
-    if os.getenv("GALILEO_DISABLED"):
+def set_config(cloud: bool = True) -> Config:
+    if galileo_disabled():
         return Config(api_url="")
     _check_console_url()
     if not os.path.isdir(ConfigData.DEFAULT_GALILEO_CONFIG_DIR.value):
@@ -151,24 +156,28 @@ def set_config() -> Config:
         config = Config(**galileo_vars)
 
     else:
-        print(f"Welcome to Galileo {dq_version}!")
-        print(
-            "To skip this prompt in the future, set the following environment "
-            "variable: GALILEO_CONSOLE_URL"
-        )
-        console_url = input("🔭 Enter the url of your Galileo console\n")
+        name = "Galileo Cloud" if cloud else "Galileo"
+        print(f"Welcome to {name} {dq_version}!")
+        if cloud:
+            console_url = CLOUD_URL
+        else:
+            print(
+                "To skip this prompt in the future, set the following environment "
+                "variable: GALILEO_CONSOLE_URL"
+            )
+            console_url = input("🔭 Enter the url of your Galileo console\n")
         set_platform_urls(console_url_str=console_url)
         galileo_vars = GalileoConfigVars.get_config_mapping()
         config = Config(**galileo_vars)
+    config.update_file_config()
     return config
 
 
-def reset_config() -> Config:
+def reset_config(cloud: bool = True) -> Config:
     """Wipe the config file and reconfigure"""
     if os.path.isfile(ConfigData.DEFAULT_GALILEO_CONFIG_FILE.value):
         os.remove(ConfigData.DEFAULT_GALILEO_CONFIG_FILE.value)
-    return set_config()
+    return set_config(cloud)
 
 
 config = set_config()
-config.update_file_config()
